@@ -3,4 +3,4 @@ from tsjPython import tsjCommonFunc
 
 a = 1
 tsjCommonFunc.passPrint(a)
-valuePrint(a)
+tsjCommonFunc.valuePrint(a)
