@@ -8,6 +8,7 @@ import inspect
 import re
 
 
+
 def valuePrint(x):
     frame = inspect.currentframe().f_back
     s = inspect.getframeinfo(frame).code_context[0]
@@ -16,13 +17,13 @@ def valuePrint(x):
 
 
 def errorPrint(message):
-    os.system('color')
+    # os.system('color')
     print(colored(message, 'red'))
     return message
 
 
 def colorPrint(message, color):
-    os.system('color')
+    # os.system('color')
     print(colored(message, color))
     return message
 
@@ -34,19 +35,19 @@ def pPrint(message):
 
 
 def yellowPrint(message):
-    os.system('color')
+    # os.system('color')
     print(colored(message, "yellow"))
     return message
 
 
 def passPrint(message):
-    os.system('color')
+    # os.system('color')
     print(colored(message, 'green'))
     return message
 
 
 def completePrint(message):
-    os.system('color')
+    # os.system('color')
     print("--------------------------------{}--------------------------------".format(colored(message, 'green')))
     return message
 
@@ -66,10 +67,60 @@ def histogramsPrint(data, type="vertical"):
         print(plotille.hist(data))
 
 
+# --------------------------------------------time--------------------------------------------------------
+
+
+class globalTimeClass:
+    count=0
+    beginTime =-1
+    lastTime =-1
+    def __init__(self,time=0):
+        self.beginTime = time
+        self.lastTime = time
+    def updateTime(self,message):
+        if self.beginTime==-1 and self.lastTime==-1:
+            splitLine("start time check")
+            current_milli_time = round(time.time() * 1000)
+            self.beginTime =current_milli_time
+            self.lastTime =current_milli_time
+            self.count =0
+        else:
+            print(message)
+            current_milli_time = round(time.time() * 1000)
+            yellowPrint("passTime {} from Last:  {:6d}ms, {:6f}s".format(self.count,current_milli_time-self.lastTime,float(current_milli_time-self.lastTime)/1000))
+            yellowPrint("passTime {} from start: {:6d}ms, {:6f}s".format(self.count,current_milli_time-self.lastTime,float(current_milli_time-self.lastTime)/1000))
+            self.lastTime =current_milli_time
+            self.count+=1
+
+globalTime = globalTimeClass(-1)
+
+
+def passTime(message="passTime:"):
+    globalTime.updateTime(message)
+
 def sleepRandom(seconds):
     time.sleep(round(random.uniform(0.15, seconds+0.15), 2))
 
 
+def testTime(whileTimes, function):
+    histogramsData = []
+    begin = time.time()
+    while whileTimes:
+        beforeFunction = time.time()
+        function()
+        afterFunction = time.time()
+        deltatime = afterFunction - beforeFunction
+        colorPrint("delta time ONECE {}".format(
+            deltatime), "yellow")
+        histogramsData.append(deltatime)
+        whileTimes -= 1
+    end = time.time()
+    colorPrint("ALL {}".format(end-begin), "red")
+    histogramsPrint(histogramsData, "horizontal")
+
+
+# --------------------------------------------valueCMP--------------------------------------------------------
+
 def Random(num):
     return round(random.uniform(0, num), 2)
 
@@ -95,18 +146,3 @@ def isArround(listA, listB, delta):
     return 1
 
 
-def testTime(whileTimes, function):
-    histogramsData = []
-    begin = time.time()
-    while whileTimes:
-        beforeFunction = time.time()
-        function()
-        afterFunction = time.time()
-        deltatime = afterFunction - beforeFunction
-        colorPrint("delta time ONECE {}".format(
-            deltatime), "yellow")
-        histogramsData.append(deltatime)
-        whileTimes -= 1
-    end = time.time()
-    colorPrint("ALL {}".format(end-begin), "red")
-    histogramsPrint(histogramsData, "horizontal")
